.. expect: inline literal missing (escaped) space after literal: "``'a'``s" (missing-space-after-literal)
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)

All 4 ``'a'``s, but, when the final ``'a'`` is encountered, the
